==> gnuradio_3.6.5.1.orig.tar.gz: gnuradio-3.6.5.1/gr-blocks/lib/rms_cf_impl.h <==
/* -*- c++ -*- */
/*
 * Copyright 2005,2013 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_BLOCKS_RMS_CF_IMPL_H
#define INCLUDED_BLOCKS_RMS_CF_IMPL_H

#include <blocks/rms_cf.h>
#include <gr_single_pole_iir.h>

namespace gr {
  namespace blocks {

    /*!
     * \brief RMS average power
     * \ingroup math_blk
     */
    class rms_cf_impl : public rms_cf
    {
    private:
      gr_single_pole_iir<double,double,double> d_iir;

    public:
      rms_cf_impl(double alpha = 0.0001);
      ~rms_cf_impl();

      void set_alpha(double alpha);
      
      int work(int noutput_items,
               gr_vector_const_void_star &input_items,
               gr_vector_void_star &output_items);

    };

  } /* namespace blocks */
} /* namespace gr */

#endif /* INCLUDED_BLOCKS_RMS_CF_IMPL_H */

==> gnuradio_3.7.2.1.orig.tar.gz: gnuradio-3.7.2.1/gr-blocks/lib/rms_cf_impl.h <==
/* -*- c++ -*- */
/*
 * Copyright 2005,2013 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * GNU Radio is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * GNU Radio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNU Radio; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_BLOCKS_RMS_CF_IMPL_H
#define INCLUDED_BLOCKS_RMS_CF_IMPL_H

#include <gnuradio/blocks/rms_cf.h>

namespace gr {
  namespace blocks {

    /*!
     * \brief RMS average power
     * \ingroup math_blk
     */
    class rms_cf_impl : public rms_cf
    {
    private:
      double d_alpha, d_beta, d_avg;

    public:
      rms_cf_impl(double alpha = 0.0001);
      ~rms_cf_impl();

      void set_alpha(double alpha);
      
      int work(int noutput_items,
               gr_vector_const_void_star &input_items,
               gr_vector_void_star &output_items);

    };

  } /* namespace blocks */
} /* namespace gr */

#endif /* INCLUDED_BLOCKS_RMS_CF_IMPL_H */
